@@ -363,6 +363,29 @@ struct entity : entity_builder<entity>
         ecs_delete(world_, id_);
     }
 
+    /** Create child */
+    template <typename ... Args>
+    flecs::entity child(flecs::entity_t r = flecs::ChildOf, Args&&... args) {
+        flecs::world world(world_);
+        return world.entity(FLECS_FWD(args)...).add(r, id_);
+    }
+
+    template <typename R, typename ... Args>
+    flecs::entity child(Args&&... args) {
+        flecs::world world(world_);
+        return world.entity(FLECS_FWD(args)...).add(_::type<R>::id(world_), id_);
+    }
+
+    /** Set child order.
+     * Changes the order of children as returned by entity::children(). Only 
+     * applicableo to entities with the flecs::OrderedChildren trait.
+     * 
+     * @see ecs_set_child_order()
+     */
+    void set_child_order(flecs::entity_t *children, int32_t child_count) const {
+        ecs_set_child_order(world_, id_, children, child_count);
+    }
+
     /** Return entity as entity_view.
      * This returns an entity_view instance for the entity which is a readonly
      * version of the entity class.
